@@ -24,115 +24,7 @@
 #include "cv.h"
 #include "exec.h"
 #include "globals.h"
-
-
-void usage(void)
-{
-	printf("%s", version_str);
-	printf("\n\nmultitail [-cs|-Cs|-c-] [-i] inputfile [-i anotherinputfile] [...]\n");
-	printf("-i x	the following parameter is a filename (in case it starts with a dash)\n");
-	printf("-I x	like -i only this one merges this logfile into the previous window\n");
-	printf("-l x	parameter is a command to be executed\n");
-	printf("-L x	see -l but add to the previous window\n");
-	printf("-j	read from stdin (can be used (of course) only once)\n");
-	printf("-J      like -j but merge into previous window\n");
-	printf("--listen [interface]:port behave like a syslog server. port is normally 514\n");
-	printf("--Listen [interface]:port like --listen but merge into previous window\n");
-	printf("-r interval    restart the command when it died after `interval' seconds\n");
-	printf("-R interval    same as -r, only with this one only the difference is displayed\n");
-	printf("-Rc/-rc interval  like -r/-R but clean the window before each iteration\n");
-	printf("--cont         reconnect lines with a '\' at the end\n");
-	printf("--mergeall     merge all of the following files into the same window (in the previous window)\n");
-	printf("--mergeall-new merge all of the following files into the same window (in a new window)\n");
-	printf("--no-mergeall  stop merging all files into one window\n");
-	printf("--no-repeat    suppress repeating lines and replace them with a \"last message repeated x times\"\n");
-	printf("--mark-interval x	when nothing comes in, print a '---mark---' line every 'x' seconds\n");
-	printf("--mark-change	when multiple files are merged an multitail switches between two windows, print a markerline with the filename\n");
-	printf("--no-mark-change	do NOT print the markerline when the file changes (overrides the configfile)\n");
-	printf("-n x	initial number of lines to tail\n");
-	printf("-m x	set scrollback buffer size (# lines)\n");
-	printf("-mb x   set scrollback buffer size (in bytes, use xKB/MB/GB)\n");
-	printf("-bw a/f what to buffer: 'a'll or what went through the 'f'ilter\n");
-	printf("-a x	like 'tee': write (filtered) input to file 'x'\n");
-	printf("-A x	see -a: but write the unfiltered(!) input to file 'x'\n");
-	printf("-g x	redirect the input also (filtered) to command/process 'x'\n");
-	printf("-G x	redirect the unfiltered input also  to command/process 'x'\n");
-	printf("--label x	put in front of each line\n");
-	printf("-q i path       check every 'i' seconds for new files in 'path', create a new window for those\n");
-	printf("-Q i path       check every 'i' seconds for new files in 'path', put them all in the same window (using subwindows)\n");
-	printf("--closeidle x   close windows when more then 'x' seconds no new data was processed\n"); 
-	printf("--new-only	(for -q/-Q) only create windows for files created after multitail was started\n");
-	printf("-s x	vertical split screen (in 'x' columns)\n");
-	printf("-sw x,x,...	at what columns to split the screen, use '0' for automatic size\n");
-	printf("-sn x,x,...     number of windows per column\n");
-	printf("-wh x	height of window\n");
-	printf("-S	prepend merged output with subwindow-number\n");
-	printf("-f	follow the following filename, not the descriptor\n");
-	printf("--follow-all	for all files after this switch; follow the filename instead of the descriptor\n");
-	printf("--retry	keep trying to open the following file if it is inaccessible\n");
-	printf("--retry-all like --retry but for all following files\n");
-	printf("-fr scheme  use the predefined filter from the configfile\n");
-	printf("-e[m]	print only when matching with this regexp\n");
-	printf("-ev	print only when NOT matching with this regexp\n");
-	printf("-ec	use regular expression but display the matches inverted on following file\n");
-	printf("-eC	use regexp, display everything but matches inverted on following file\n");
-	printf("-ex	execute command ('-ex regexp command') when matches, matching line is given as commandline parameter\n");
-	printf("-eX     like -ex but only give the matching substring as commandline parameter to the command\n");
-	printf("-E	use regular expression on following files\n");
-	printf("-Ec	use regular expression but display the matches inverted on following files\n");
-	printf("-EC	use regexp, display everything but matches inverted on following files\n");
-	printf("-ke x   strip parts of the input using regular expression 'x'\n");
-	printf("-kr x y strip parts of the input starting at offset x and ending (not including!) offset y\n");
-	printf("-kc x y strip parts of the input: strip column 'y' with delimiter 'x'\n");
-	printf("-ks x   use edit scheme 'x' (defined in configfile)\n");
-	printf("-kS x   only show the substrings matched by the substring-selects (the parts between '(' and ')') in the regular epxression 'x'\n");
-	printf("-v      invert next regular expression (do not use with -ev/em)\n");
-	printf("-cv x	use conversion scheme 'x' (see multitail.conf)\n");
-	printf("-c	colorize current\n");
-	printf("-cS scheme	use colorscheme 'scheme' (as defined in multitail.conf)\n");
-	printf("-csn    extra switch for the following switches; do not use reverse (inverted) colors\n");
-	printf("-Cs	colorize all following files with syslog-scheme\n");
-	printf("-C	colorize all following files\n");
-	printf("-Cf/-cf field delimiter		colorize next/all file(s) depending on the given field number. fields are delimited with the given field-delimiter\n");
-	printf("-ci color  use 'color' (red, green, etc), usefull when merging multiple inputs\n");
-	printf("-c-	do NOT colorize the following file\n");
-	printf("-C-	do NOT colorize the following files\n");
-	printf("-cT term	interpret terminal-codes from file/command (for terminal type 'term')\n");
-	printf("-Z color   set color for markerline\n");
-	printf("-ts	add a timestamp (format configurable in multitail.conf) before each line\n");
-	printf("-T      put a timestamp in markerlines\n");
-	printf("-d	do NOT update the status-line\n");
-	printf("-D	do not display a status-line at all\n");
-	printf("-du     put the statusline above the data window\n");
-	printf("-z	do not \"window closed\" windows\n");
-	printf("-w	do not use colors\n");
-	printf("-u	set update interval (for slow links)\n");
-	printf("-p x [y]	set linewrap (l=left/a=all/r=right/s=syslog,S=syslog w/o procname,o=offset -> 'y',w=wordwrap)\n");
-	printf("-P      like -p but for all following files\n");
-	printf("-b n	set TAB-width\n");
-	printf("--basename	only display the filename (and not the path) in the statusline\n");
-	printf("-x str	switch on the xtermtitlebar stuff\n");
-#ifndef S_SPLINT_S
-	printf("-F file   use 'file' as configfile (instead of " CONFIG_FILE ")\n");
-	printf("--no-load-global-config do not read " CONFIG_FILE "\n");
-#endif
-	printf("-o configfileparameter    do a setting which would normally be set in the configfile\n");
-	printf("-H x	show heartbeat (to keep your sessions alive)\n");
-	printf("-iw file i	check every 'i' seconds if 'file' appeared in the filesystem\n");
-	printf("-t x	display 'x' in the window-title (when MultiTail runs in an xterm)\n");
-	printf("--beep-interval x	beep every x lines processed\n");
-	printf("--bi x	like '--beep-interval' but only for current (sub-)window\n");
-	printf("-V	show version and exit\n");
-	printf("-h	this help\n");
-	printf("\n");
-	printf("You can have multiple regular expressions per file/command. Be warned: if\n");
-	printf("you define multiple and one of them is specified with '-E' (=for every\n");
-	printf("following file), _all_ of the current regular expressions are for all\n");
-	printf("following files!\n");
-	printf("\n");
-
-	printf("%s\n", F1);
-}
+#include "help.h"
 
 void add_redir_to_file(char mode, char *file, redirect_t **predir, int *n_redirect)
 {
@@ -150,7 +42,7 @@ void add_redir_to_file(char mode, char *file, redirect_t **predir, int *n_redire
 
 	(*predir)[cur_index].fd = open((*predir)[cur_index].redirect, O_WRONLY | O_CREAT | O_APPEND, S_IRUSR | S_IWUSR);
 	if ((*predir)[cur_index].fd == -1)
-		error_exit("%s: cannot open file %s for write access.\n", file, (*predir)[cur_index].redirect);
+		error_exit(TRUE, FALSE, "%s: cannot open file %s for write access.\n", file, (*predir)[cur_index].redirect);
 }
 
 void add_redir_to_proc(char mode, char *proc, redirect_t **predir, int *n_redirect)
@@ -161,7 +53,7 @@ void add_redir_to_proc(char mode, char *proc, redirect_t **predir, int *n_redire
 
 	*predir = (redirect_t *)myrealloc(*predir, (*n_redirect + 1) * sizeof(redirect_t));
 
-	if ((*predir)[*n_redirect].type != REDIRECTTO_NONE) error_exit("One can only set one redirection-type per (sub-)window.\n");
+	if ((*predir)[*n_redirect].type != REDIRECTTO_NONE) error_exit(FALSE, FALSE, "One can only set one redirection-type per (sub-)window.\n");
 
 	if (mode == 'g')
 		(*predir)[*n_redirect].type = REDIRECTTO_PIPE_FILTERED;
@@ -224,7 +116,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 
 	s = getaddrinfo(node, service, &hints, &result);
 	if (s != 0)
-		error_exit("Cannot create socket for redirecting via syslog protocol: %s.\n", gai_strerror(s));
+		error_exit(TRUE, FALSE, "Cannot create socket for redirecting via syslog protocol: %s.\n", gai_strerror(s));
 
 	for (rp = result; rp != NULL; rp = rp -> ai_next)
 	{
@@ -239,7 +131,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 	freeaddrinfo(result);
 
 	if (rp == NULL)
-		error_exit("Cannot create socket for redirecting via syslog protocol.\n");
+		error_exit(FALSE, FALSE, "Cannot create socket for redirecting via syslog protocol.\n");
 
 	(*predir)[*n_redirect].fd = sfd;
 	
@@ -252,7 +144,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 		}
 	}
 	if (prio_nr == -1)
-		error_exit("Priority '%s' is not recognized.\n", prio);
+		error_exit(FALSE, FALSE, "Priority '%s' is not recognized.\n", prio);
 	
 	for(loop=0; loop<24; loop++)
 	{
@@ -263,7 +155,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 		}
 	}
 	if (fac_nr == -1)
-		error_exit("Facility '%s' is not known.\n", fac);
+		error_exit(FALSE, FALSE, "Facility '%s' is not known.\n", fac);
 
 	(*predir)[*n_redirect].prio_fac = (fac_nr * 8) + prio_nr;
 
@@ -275,7 +167,7 @@ void add_redir_to_socket(char filtered, char *prio, char *fac, char *address, re
 void argv_set_window_widths(char *widths)
 {
 	if (split != 0)
-		error_exit("-s and -sw are mutual exclusive.\n");
+		error_exit(FALSE, FALSE, "-s and -sw are mutual exclusive.\n");
 
 	split = 0;
 	for(;;)
@@ -297,14 +189,14 @@ void argv_set_window_widths(char *widths)
 			if (cur_width == 0)
 				cur_width = -1;
 			else
-				error_exit("The width of a column must be 4 or greater (or '0' for automatic size).\n");
+				error_exit(FALSE, FALSE, "The width of a column must be 4 or greater (or '0' for automatic size).\n");
 		}
 
 		vertical_split[split - 1] = cur_width;
 	}
 
 	if (split == 1)
-		error_exit("You have to give the width for each window or set it to 0 (=auto width).\n");
+		error_exit(FALSE, FALSE, "You have to give the width for each window or set it to 0 (=auto width).\n");
 }
 
 void argv_set_n_windows_per_column(char *pars)
@@ -312,7 +204,7 @@ void argv_set_n_windows_per_column(char *pars)
 	int index = 0;
 
 	if (split == 0)
-		error_exit("First use -s or -sw to define the number of columns.\n");
+		error_exit(FALSE, FALSE, "First use -s or -sw to define the number of columns.\n");
 
 	for(;;)
 	{
@@ -329,7 +221,7 @@ void argv_set_n_windows_per_column(char *pars)
 		pars = NULL;
 
 		if (cur_n < 0)
-			error_exit("The number of windows must be either 0 (=auto) or >= 1.\n");
+			error_exit(FALSE, FALSE, "The number of windows must be either 0 (=auto) or >= 1.\n");
 
 		n_win_per_col[index - 1] = cur_n;
 	}
@@ -362,7 +254,7 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 	else if (toupper(mode[2]) == 'X')
 		regex_mode = mode[2];	/* x = execute */
 	else
-		error_exit("%s is an unknown switch.\n", mode);
+		error_exit(FALSE, FALSE, "%s is an unknown switch.\n", mode);
 
 	/* get expression */
 	expr = pars[n_pars_used++];
@@ -373,7 +265,7 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 		cmd = pars[n_pars_used++];
 
 		if (regex_mode == 'X' && (strchr(expr, '(') == NULL || strchr(expr, ')') == NULL))
-			error_exit("Filterscheme rule: -eX requires a regular expression which selects a substring using '(' and ')'.\n");
+			error_exit(FALSE, FALSE, "Filterscheme rule: -eX requires a regular expression which selects a substring using '(' and ')'.\n");
 	}
 
 	/* compile & set expression */
@@ -397,7 +289,7 @@ int argv_add_re(char *mode, char *pars[], char invert_regex, re **pre_cur, int *
 	/* wether to invert the reg exp or not */
 	if ((regex_mode == 'v' || regex_mode == 'm') && invert_regex)
 	{
-		error_exit("-e[m] / -ev cannot be used together with -v\n");
+		error_exit(FALSE, FALSE, "-e[m] / -ev cannot be used together with -v\n");
 	}
 	(*pre)[*n_re].invert_regex = invert_regex;
 
@@ -437,7 +329,7 @@ int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor
 		if (pars[n_pars_used] != NULL && (strcasecmp(pars[n_pars_used], "ANSI") == 0 || strcasecmp(pars[n_pars_used], "vt100") == 0))
 			*cur_term_emul = TERM_ANSI;
 		else
-			error_exit("Terminal emulation '%s' is not known.\n", pars[n_pars_used]);
+			error_exit(FALSE, FALSE, "Terminal emulation '%s' is not known.\n", pars[n_pars_used]);
 
 		n_pars_used++;
 	}
@@ -446,14 +338,14 @@ int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor
 		int cur_scheme_index;
 		char *cur_cscheme = pars[n_pars_used++];
 		if (!cur_cscheme)
-			error_exit("%s requires a color scheme name.\n", mode);
+			error_exit(FALSE, FALSE, "%s requires a color scheme name.\n", mode);
 
 		if ((cur_scheme_index = find_colorscheme(cur_cscheme)) == -1)
 		{
 			if (use_colors)
-				error_exit("Color scheme %s not found! Please check your configuration file.\n", cur_cscheme);
+				error_exit(FALSE, FALSE, "Color scheme %s not found! Please check your configuration file.\n", cur_cscheme);
 			else
-				error_exit("Color schemes are not supported on monochrome terminals.\n");
+				error_exit(FALSE, FALSE, "Color schemes are not supported on monochrome terminals.\n");
 		}
 
 		add_color_scheme(cur_color_schemes, cur_scheme_index);
@@ -473,7 +365,7 @@ int argv_color_settings(char *mode, char *pars[], char *allcolor, char *curcolor
 	}
 	else
 	{
-		error_exit("Invalid -c mode: '%c'.\n", cur_mode);
+		error_exit(FALSE, FALSE, "Invalid -c mode: '%c'.\n", cur_mode);
 	}
 
 	if (doall)
@@ -516,7 +408,7 @@ int argv_add_stripper(char *mode, char *pars[], strip_t **pstrip, int *n_strip)
 		(*pstrip)[*n_strip].end = get_value_arg(mode, pars[n_pars_used++], VAL_ZERO_POSITIVE);
 		(*pstrip)[*n_strip].del = NULL;
 		if ((*pstrip)[*n_strip].end <= (*pstrip)[*n_strip].start)
-			error_exit("'-kr start end': end must be higher then start.\n");
+			error_exit(FALSE, FALSE, "'-kr start end': end must be higher then start.\n");
 		(*n_strip)++;
 	}
 	else if (mode[2] == 'c')
@@ -532,16 +424,16 @@ int argv_add_stripper(char *mode, char *pars[], strip_t **pstrip, int *n_strip)
 		char *scheme = pars[n_pars_used++];
 		int editscheme_index = find_editscheme(scheme);
 		if (editscheme_index == -1)
-			error_exit("-ks %s: scheme not found.\n", scheme);
+			error_exit(FALSE, FALSE, "-ks %s: scheme not found.\n", scheme);
 		duplicate_es_array(pes[editscheme_index].strips, pes[editscheme_index].n_strips, pstrip, n_strip);
 	}
 	else
-		error_exit("'%s' is not recognized.\n", mode);
+		error_exit(FALSE, FALSE, "'%s' is not recognized.\n", mode);
 
 	return n_pars_used;
 }
 
-void add_glob_check(char *check_glob, int check_interval, char merge, char new_only)
+void add_glob_check(const char *check_glob, int check_interval, char merge, char new_only, const char *cs)
 {
 	cdg = (check_dir_glob *)myrealloc(cdg, sizeof(check_dir_glob) * (n_cdg + 1));
 
@@ -551,6 +443,7 @@ void add_glob_check(char *check_glob, int check_interval, char merge, char new_o
 	cdg[n_cdg].new_only       = new_only;
 	cdg[n_cdg].window_nr      = -1;
 	cdg[n_cdg].last_check     = (dtime_t)0.0;
+	cdg[n_cdg].color_scheme   = cs;
 	n_cdg++;
 }
 
@@ -646,10 +539,10 @@ void do_commandline(int argc, char *argv[])
 				if (what[0] == 'a' || what[0] == 'f')
 					bufferwhat = what[0];
 				else
-					error_exit("-bw expects either 'a' or 'f' as parameter (got: '%c').\n", what[0]);
+					error_exit(FALSE, FALSE, "-bw expects either 'a' or 'f' as parameter (got: '%c').\n", what[0]);
 			}
 			else
-				error_exit("-bw expects a parameter ('a' or 'f').\n");
+				error_exit(FALSE, FALSE, "-bw expects a parameter ('a' or 'f').\n");
 		}
 		else if (strcmp(argv[loop], "--no-repeat") == 0)
 		{
@@ -695,10 +588,10 @@ void do_commandline(int argc, char *argv[])
 			if (argv[loop])
 			{
 				heartbeat_interval = atof(argv[loop]);
-				if (heartbeat_interval < 0.0) error_exit("The value for -H must be >= 0.\n");
+				if (heartbeat_interval < 0.0) error_exit(FALSE, FALSE, "The value for -H must be >= 0.\n");
 			}
 			else
-				error_exit("-H requires a parameter.\n");
+				error_exit(FALSE, FALSE, "-H requires a parameter.\n");
 		}
 		else if (strcasecmp(argv[loop], "-a") == 0)
 		{
@@ -719,7 +612,7 @@ void do_commandline(int argc, char *argv[])
 
 			// -U[af][as] <facil> <prio> host[:port]
 			if (argv[loop][2] != 'a' && argv[loop][2] != 'f')
-				error_exit("-Ux where x needs to be either 'a' or 'f'");
+				error_exit(FALSE, FALSE, "-Ux where x needs to be either 'a' or 'f'");
 
 			filtered = argv[loop][2] == 'f';
 			prio = argv[++loop];
@@ -732,7 +625,7 @@ void do_commandline(int argc, char *argv[])
 		{
 			config_file = argv[++loop];
 			if (file_exist(config_file) == -1)
-				error_exit("Configuration file %s does not exist.\n", config_file);
+				error_exit(FALSE, FALSE, "Configuration file %s does not exist.\n", config_file);
 
 			(void)do_load_config(-1, NULL, config_file);
 		}
@@ -752,14 +645,14 @@ void do_commandline(int argc, char *argv[])
 		{
 			++loop;
 			if (!argv[loop])
-				error_exit("-t requires a parameter.\n");
+				error_exit(FALSE, FALSE, "-t requires a parameter.\n");
 			win_title = mystrdup(argv[loop]);
 		}
 		else if (strcmp(argv[loop], "-x") == 0)
 		{
 			++loop;
 			if (!argv[loop])
-				error_exit("-x requires a parameter.\n");
+				error_exit(FALSE, FALSE, "-x requires a parameter.\n");
 			set_title = mystrdup(argv[loop]);
 		}
 		else if (argv[loop][0] == '-' && toupper(argv[loop][1]) == 'P')
@@ -775,10 +668,10 @@ void do_commandline(int argc, char *argv[])
 				if (cur_line_wrap == 'o')
 					cur_line_wrap_offset = get_value_arg("-p", argv[++loop], VAL_ZERO_POSITIVE);
 				else if (cur_line_wrap != 'a' && cur_line_wrap != 'l' && cur_line_wrap != 'r' && toupper(cur_line_wrap) != 'S' && cur_line_wrap != 'w')
-					error_exit("Invalid mode for -p\n");
+					error_exit(FALSE, FALSE, "Invalid mode for -p\n");
 			}
 			else
-				error_exit("-p requires a parameter.\n");
+				error_exit(FALSE, FALSE, "-p requires a parameter.\n");
 		}
 		else if (strcmp(argv[loop], "--retry") == 0)
 		{
@@ -843,7 +736,7 @@ void do_commandline(int argc, char *argv[])
 
 				filter = find_filterscheme(par);
 				if (filter == -1)
-					error_exit("'%s' is not a known filter scheme.\n", par);
+					error_exit(FALSE, FALSE, "'%s' is not a known filter scheme.\n", par);
 
 				duplicate_re_array(pfs[filter].pre, pfs[filter].n_re, &pre, &n_re);
 
@@ -941,7 +834,7 @@ void do_commandline(int argc, char *argv[])
 			}
 			else if (strcasecmp(argv[loop], "-j") == 0)
 			{
-				if (used_stdin == MY_TRUE) error_exit("One can use %s only once.\n", argv[loop]);
+				if (used_stdin == MY_TRUE) error_exit(FALSE, FALSE, "One can use %s only once.\n", argv[loop]);
 				is_stdin = used_stdin = 1;
 			}
 			else if (strcasecmp(argv[loop], "-iw") == 0)
@@ -959,7 +852,7 @@ void do_commandline(int argc, char *argv[])
 					}
 				}
 				else
-					error_exit("-iw requires 2 parameters.\n");
+					error_exit(FALSE, FALSE, "-iw requires 2 parameters.\n");
 			}
 			else if (strcasecmp(argv[loop], "--listen") == 0)
 			{
@@ -1046,7 +939,7 @@ void do_commandline(int argc, char *argv[])
 			/* init. struct. for this file */
 			if (is_stdin == 0)
 			{
-				if (!dummy) error_exit("No filename given.\n");
+				if (!dummy) error_exit(FALSE, FALSE, "No filename given.\n");
 				cur -> filename = mystrdup(dummy);
 			}
 			else
@@ -1218,18 +1111,27 @@ void do_commandline(int argc, char *argv[])
 				else if (strcasecmp(type, "ctime") == 0)
 					new_only = TT_CTIME;
 				else
-					error_exit("--new-only requires either atime, mtime or ctime as parameter, not '%s'.\n", type);
+					error_exit(FALSE, FALSE, "--new-only requires either atime, mtime or ctime as parameter, not '%s'.\n", type);
 			}
 			else
-				error_exit("--new-only requires a parameter.\n");
+				error_exit(FALSE, FALSE, "--new-only requires a parameter.\n");
 		}
-		else if (strcasecmp(argv[loop], "-q") == 0)
+		else if (strcasecmp(argv[loop], "-q") == 0 || strcasecmp(argv[loop], "-qs") == 0)
 		{
-			int merge = argv[loop][1] == 'Q';
-			int check_interval = get_value_arg("-q/-Q", argv[++loop], VAL_ZERO_POSITIVE);
-			char *check_glob = argv[++loop];
+			int cmd_index = loop;
+			int merge = argv[cmd_index][1] == 'Q';
+			int check_interval = get_value_arg("-q[s]/-Q[s]", argv[++loop], VAL_ZERO_POSITIVE);
+			const char *default_color_scheme = NULL, *check_glob = NULL;
 
-			add_glob_check(check_glob, check_interval, merge, new_only);
+			if (argv[cmd_index][2] == 's')
+				default_color_scheme = argv[++loop];
+
+			check_glob = argv[++loop];
+
+			if (default_color_scheme && find_colorscheme(default_color_scheme) == -1)
+				error_exit(FALSE, FALSE, "Color scheme '%s' is not known.\n", default_color_scheme);
+
+			add_glob_check(check_glob, check_interval, merge, new_only, default_color_scheme);
 		}
 		else if (strcmp(argv[loop], "--mark-change") == 0)
 		{
@@ -1244,7 +1146,7 @@ void do_commandline(int argc, char *argv[])
 			loop++;
 
 			if (!argv[loop])
-				error_exit("-o requires a parameter.\n");
+				error_exit(FALSE, FALSE, "-o requires a parameter.\n");
 			else
 				config_file_entry(-1, argv[loop]);
 		}
@@ -1259,7 +1161,7 @@ void do_commandline(int argc, char *argv[])
 		else
 		{
 			if (strcmp(argv[loop], "-h") != 0)
-				fprintf(stderr, "unknown parameter '%s'\n", argv[loop]);
+				fprintf(stderr, "\nunknown parameter '%s'\n\n", argv[loop]);
 
 			usage();
 
